@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 our $VERSION;
-$VERSION = '0.02_02';
+$VERSION = '0.03_01';
 
 =encoding utf-8
 
@@ -285,7 +285,9 @@ sub runtests {
         $self = $obj;
     }
 
-    my $ctx = Test2::API::context();
+    my $big_ctx = Test2::API::context();
+    my $ctx = $big_ctx->snapshot();
+    $big_ctx->release();
 
     if (my $reason = $self->SKIP_CLASS()) {
         $ctx->plan(1);
@@ -372,8 +374,6 @@ sub runtests {
         }
     }
 
-    $ctx->release();
-
     return;
 }
 
